/*
Radiant Technologies, Inc.
4 April 2015 -- STS

FeCap_Read_WriteDown
Simple Arduino example to Read and display the state of Radiant Technologies' 
ferroelectric capacitor (polled or erased), then poll the FeCap DOWN and 
wait for next restart.

The Arduino can then be powered off, enabling zero power event detection.
Used with the MEAS-SPEC piezo flapper.  

The FeCap is previously polled DOWN.  When the flapper is tripped, the 
FeCap becomes erased.  The LED will display OFF for no event 
(FeCap still polled DOWN) or ON for event detected (FeCap erased). 

*/
//     define pins 
int C_Fe = 3;     // use pin 3 as voltage on C_FE
int C_Sense = 2;  // use pin 2 as voltage on C_Sense 
int FeCap = 0;    // storage for FeCap read value 
int ledPin = 13;  // arduino LED connected to pin 13
int Gate = 4;    // use pin4 as gate drive

// the setup routine runs once when you press reset:
void setup() {                
// initial pin voltage conditions...both low
  digitalWrite(C_Fe, LOW);   // initial condition LOW
  digitalWrite(C_Sense, LOW);   // initial condition LOW
  digitalWrite(ledPin, LOW);  // Arduino LED pin LOW (off)
  digitalWrite(Gate, HIGH);   // initial condition HIGH 
  
 // initial pin drive conditions...CFe and CSense input, others output
  pinMode(C_Fe, INPUT);    
  pinMode(C_Sense, INPUT); 
  pinMode(ledPin, OUTPUT);  // use Arduino LED to display FeCap state 
  pinMode(Gate, OUTPUT); 

// perform the read
  pinMode(C_Fe, OUTPUT);  // set C_Fe pin as output....still LOW
  digitalWrite(C_Fe, HIGH);   // set C_Fe pin HIGH
  FeCap = digitalRead(C_Sense);   // read the sense capacitor
// if the FeCap is still polled down (reads HIGH) then no event occurred.  Leave LED OFF
// if the FeCap is erased (reads LOW), then event occurred.  Turn LED ON
  delay(1);              // 1ms delay to shape oscilloscope image
  digitalWrite(C_Fe, LOW);   // set C_Fe pin back LOW -- default state 
  pinMode(C_Fe, INPUT);  // set C_Fe pin to input -- default state
  digitalWrite(ledPin, !FeCap);  // use LED to indicate event detected

//  Write DOWN  
//      Coming into this, FeCAP and C_Sense are inputs, with LOWS in their
//      output latches.
//
  delay(10);      // 10 ms delay for scope formatting

// set pins to outputs
  pinMode(C_Fe, OUTPUT);    
  pinMode(C_Sense, OUTPUT); 
//Write DOWN
  digitalWrite(C_Sense, HIGH);   // HIGH on C_Sense)
  delay(1);      // 1 ms delay
  digitalWrite(C_Sense, LOW);   // LOW on C_Sense)

// Retain with pins as inputs
  pinMode(C_Fe, INPUT);    
  pinMode(C_Sense, INPUT);
  digitalWrite(Gate, LOW);   // turn off mosfet    
} 
void loop() {}

